==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ew201.c <==
/*
 * Code for class EW_TEST_ENVIRONMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew201.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_TEST_ENVIRONMENT}.make */
void F643_3634 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 642, Current, 0, 1, 5984);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {663,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F659_3767(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,899,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F646_3682(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = F202_2264(Current);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.define */
void F643_3635 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("define", 642, Current, 0, 2, 5985);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F659_3814(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove */
void F643_3636 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove", 642, Current, 0, 1, 5986);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F659_3819(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.add_environment_variable */
void F643_3637 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("add_environment_variable", 642, Current, 0, 2, 5987);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F659_3814(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove_environment_variable */
void F643_3638 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_environment_variable", 642, Current, 0, 1, 5988);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F659_3819(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.set_max_c_processes */
void F643_3639 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_max_c_processes", 642, Current, 0, 1, 5989);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.substitute */
EIF_REFERENCE F643_3641 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc4 = (EIF_CHARACTER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,loc5);
	RTLR(5,loc6);
	RTLIU(6);
	
	RTEAA("substitute", 642, Current, 8, 1, 5991);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4379[Dtype(arg1)-894]);
	F895_5681(RTCW(tr1), ti4_1);
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4379[Dtype(arg1)-894]);
	RTHOOK(3);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(4);
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		RTHOOK(5);
		loc4 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4226[Dtype(arg1)-895])(RTCW(arg1), loc1);
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 36U)) {
			RTHOOK(7);
			if (loc7) {
				RTHOOK(8);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				RTHOOK(9);
				F897_5809(RTCW(Result), loc4);
			} else {
				RTHOOK(10);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(11);
			if (loc7) {
				RTHOOK(12);
				if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 40U)) {
					RTHOOK(13);
					loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					RTHOOK(14);
					loc3 = (EIF_INTEGER_32) loc1;
					for (;;) {
						RTHOOK(15);
						tb1 = '\01';
						if (!(EIF_BOOLEAN) (loc1 > loc2)) {
							tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4226[Dtype(arg1)-895])(RTCW(arg1), loc1);
							tb1 = (EIF_BOOLEAN) !F38_581(Current, tw1);
						}
						if (tb1) break;
						RTHOOK(16);
						loc1++;
					}
					RTHOOK(17);
					loc1--;
					RTHOOK(18);
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4303[Dtype(arg1)-895])(RTCW(arg1), loc3, loc1);
					RTHOOK(19);
					loc6 = F643_3642(Current, loc5);
					RTHOOK(20);
					if ((EIF_BOOLEAN)(loc6 != NULL)) {
						RTHOOK(21);
						F897_5794(RTCW(Result), loc6);
					} else {
						RTHOOK(22);
						F897_5809(RTCW(Result), (EIF_CHARACTER_32) 36U);
						RTHOOK(23);
						F897_5794(RTCW(Result), loc5);
					}
					RTHOOK(24);
					if (loc8) {
						RTHOOK(25);
						loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
						RTHOOK(26);
						loc1++;
					}
					RTHOOK(27);
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				}
			} else {
				RTHOOK(28);
				F897_5809(RTCW(Result), loc4);
			}
		}
		RTHOOK(29);
		loc1++;
	}
	RTHOOK(30);
	if (loc7) {
		RTHOOK(31);
		F897_5809(RTCW(Result), loc4);
	}
	RTHOOK(32);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.value */
EIF_REFERENCE F643_3642 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("value", 642, Current, 0, 1, 5992);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F659_3772(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.replaced_variable */
EIF_REFERENCE F643_3643 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("replaced_variable", 642, Current, 0, 1, 5993);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4379[Dtype(arg1)-894]);
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4226[Dtype(arg1)-895])(RTCW(arg1), ((EIF_INTEGER_32) 1L));
		tb1 = (EIF_BOOLEAN)(tw1 == (EIF_CHARACTER_32) 36U);
	}
	if (tb1) {
		RTHOOK(2);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4379[Dtype(arg1)-894]);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4303[Dtype(arg1)-895])(RTCW(arg1), ((EIF_INTEGER_32) 2L), ti4_1);
		tr1 = F643_3642(Current, tr1);
		Result = F892_5610(RTCW(tr1));
	}
	RTHOOK(3);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
		RTHOOK(4);
		Result = F892_5610(RTCW(arg1));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) Result;
	}
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.environment_variables */
EIF_REFERENCE F643_3645 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {EW_TEST_ENVIRONMENT}.table */
EIF_REFERENCE F643_3646 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_TEST_ENVIRONMENT}.list */
EIF_REFERENCE F643_3647 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


void EIF_Minit201 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ew201.c <==
/*
 * Code for class EW_TEST_ENVIRONMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew201.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_TEST_ENVIRONMENT}.make */
void F643_3641 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 642, Current, 0, 1, 5991);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {663,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F659_3774(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,899,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F646_3689(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = F202_2265(Current);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.define */
void F643_3642 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("define", 642, Current, 0, 2, 5992);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F659_3821(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove */
void F643_3643 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove", 642, Current, 0, 1, 5993);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F659_3826(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.add_environment_variable */
void F643_3644 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("add_environment_variable", 642, Current, 0, 2, 5994);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F659_3821(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove_environment_variable */
void F643_3645 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_environment_variable", 642, Current, 0, 1, 5995);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F659_3826(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.set_max_c_processes */
void F643_3646 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_max_c_processes", 642, Current, 0, 1, 5996);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.substitute */
EIF_REFERENCE F643_3648 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc4 = (EIF_CHARACTER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLIU(5);
	
	RTEAA("substitute", 642, Current, 8, 1, 5998);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(896, 0x00).id, 896, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4400[Dtype(arg1)-894]);
	F895_5702(RTCW(Result), ti4_1);
	RTHOOK(2);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4400[Dtype(arg1)-894]);
	RTHOOK(3);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(4);
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		RTHOOK(5);
		loc4 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4247[Dtype(RTCW(arg1))-895])(arg1, loc1);
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 36U)) {
			RTHOOK(7);
			if (loc7) {
				RTHOOK(8);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				RTHOOK(9);
				F897_5830(RTCW(Result), loc4);
			} else {
				RTHOOK(10);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(11);
			if (loc7) {
				RTHOOK(12);
				if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 40U)) {
					RTHOOK(13);
					loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					RTHOOK(14);
					loc3 = (EIF_INTEGER_32) loc1;
					for (;;) {
						RTHOOK(15);
						tb1 = '\01';
						if (!(EIF_BOOLEAN) (loc1 > loc2)) {
							tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4247[Dtype(RTCW(arg1))-895])(arg1, loc1);
							tb1 = (EIF_BOOLEAN) !F38_581(Current, tw1);
						}
						if (tb1) break;
						RTHOOK(16);
						loc1++;
					}
					RTHOOK(17);
					loc1--;
					RTHOOK(18);
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4324[Dtype(RTCW(arg1))-895])(arg1, loc3, loc1);
					RTHOOK(19);
					loc6 = F643_3649(Current, loc5);
					RTHOOK(20);
					if ((EIF_BOOLEAN)(loc6 != NULL)) {
						RTHOOK(21);
						F897_5815(RTCW(Result), loc6);
					} else {
						RTHOOK(22);
						F897_5830(RTCW(Result), (EIF_CHARACTER_32) 36U);
						RTHOOK(23);
						F897_5815(RTCW(Result), loc5);
					}
					RTHOOK(24);
					if (loc8) {
						RTHOOK(25);
						loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
						RTHOOK(26);
						loc1++;
					}
					RTHOOK(27);
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				}
			} else {
				RTHOOK(28);
				F897_5830(RTCW(Result), loc4);
			}
		}
		RTHOOK(29);
		loc1++;
	}
	RTHOOK(30);
	if (loc7) {
		RTHOOK(31);
		F897_5830(RTCW(Result), loc4);
	}
	RTHOOK(32);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.value */
EIF_REFERENCE F643_3649 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("value", 642, Current, 0, 1, 5999);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F659_3779(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.replaced_variable */
EIF_REFERENCE F643_3650 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("replaced_variable", 642, Current, 0, 1, 6000);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4400[Dtype(arg1)-894]);
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4247[Dtype(RTCW(arg1))-895])(arg1, ((EIF_INTEGER_32) 1L));
		tb1 = (EIF_BOOLEAN)(tw1 == (EIF_CHARACTER_32) 36U);
	}
	if (tb1) {
		RTHOOK(2);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4400[Dtype(arg1)-894]);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4324[Dtype(RTCW(arg1))-895])(arg1, ((EIF_INTEGER_32) 2L), ti4_1);
		tr1 = F643_3649(Current, tr1);
		Result = F892_5631(RTCW(tr1));
	}
	RTHOOK(3);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
		RTHOOK(4);
		Result = F892_5631(RTCW(arg1));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) Result;
	}
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit201 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
